==> adams-visualstats-0.3.5-sources.jar: adams/gui/visualization/stats/fourinone/VersusOrderOptions.java <==
/*
 * VersusOrderOptions.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.stats.fourinone;

import adams.core.option.OptionHandlingObject;
import adams.gui.visualization.stats.paintlet.VsOrderPaintlet;

/**
 <!-- globalinfo-start -->
 * Class containing the options for the versus order plot
 * <p/>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <p/>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 * <pre>-paintlet &lt;adams.gui.visualization.stats.paintlet.VsOrderPaintlet&gt; (property: paintlet)
 * &nbsp;&nbsp;&nbsp;painlet for plotting the vs fit plot
 * &nbsp;&nbsp;&nbsp;default: adams.gui.visualization.stats.paintlet.VsOrderPaintlet
 * </pre>
 *
 <!-- options-end -->
 *
 * @author msf8
 * @version $Revision: 3270 $
 */
public class VersusOrderOptions
extends OptionHandlingObject{

  /** for serialization */
  private static final long serialVersionUID = -4737656972085433346L;

  /** Paintlet for plotting the data */
  protected VsOrderPaintlet m_Val;

  public String globalInfo() {
    return "Class containing the options for the versus order plot";
  }


  public void defineOptions() {
    super.defineOptions();
    //paintlet for plotting the data
    m_OptionManager.add(
	"paintlet", "paintlet", new VsOrderPaintlet());

  }

  /**
   * Set the paintlet for the versus order plot
   * @param val			Paintlet for plotting the data
   */
  public void setPaintlet(VsOrderPaintlet val) {
    m_Val = val;
  }

  /**
   * Get the paintlet for the versus order plot
   * @return			Paintlet for plotting the data
   */
  public VsOrderPaintlet getPaintlet() {
    return m_Val;
  }

  /**
   * Tip Text for the paintlet property
   * @return			String to describe this property
   */
  public String paintletTipText() {
    return "painlet for plotting the vs fit plot";
  }
}

==> adams-visualstats-0.3.8-sources.jar: adams/gui/visualization/stats/fourinone/VersusOrderOptions.java <==
/*
 * VersusOrderOptions.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */

package adams.gui.visualization.stats.fourinone;

import adams.core.option.AbstractOptionHandler;
import adams.gui.visualization.stats.paintlet.VsOrderPaintlet;

/**
 <!-- globalinfo-start -->
 * Class containing the options for the versus order plot
 * <p/>
 <!-- globalinfo-end -->
 *
 <!-- options-start -->
 * Valid options are: <p/>
 *
 * <pre>-D &lt;int&gt; (property: debugLevel)
 * &nbsp;&nbsp;&nbsp;The greater the number the more additional info the scheme may output to
 * &nbsp;&nbsp;&nbsp;the console (0 = off).
 * &nbsp;&nbsp;&nbsp;default: 0
 * &nbsp;&nbsp;&nbsp;minimum: 0
 * </pre>
 *
 * <pre>-paintlet &lt;adams.gui.visualization.stats.paintlet.VsOrderPaintlet&gt; (property: paintlet)
 * &nbsp;&nbsp;&nbsp;painlet for plotting the vs fit plot
 * &nbsp;&nbsp;&nbsp;default: adams.gui.visualization.stats.paintlet.VsOrderPaintlet
 * </pre>
 *
 <!-- options-end -->
 *
 * @author msf8
 * @version $Revision: 4397 $
 */
public class VersusOrderOptions
extends AbstractOptionHandler{

  /** for serialization */
  private static final long serialVersionUID = -4737656972085433346L;

  /** Paintlet for plotting the data */
  protected VsOrderPaintlet m_Val;

  public String globalInfo() {
    return "Class containing the options for the versus order plot";
  }


  public void defineOptions() {
    super.defineOptions();
    //paintlet for plotting the data
    m_OptionManager.add(
	"paintlet", "paintlet", new VsOrderPaintlet());

  }

  /**
   * Set the paintlet for the versus order plot
   * @param val			Paintlet for plotting the data
   */
  public void setPaintlet(VsOrderPaintlet val) {
    m_Val = val;
  }

  /**
   * Get the paintlet for the versus order plot
   * @return			Paintlet for plotting the data
   */
  public VsOrderPaintlet getPaintlet() {
    return m_Val;
  }

  /**
   * Tip Text for the paintlet property
   * @return			String to describe this property
   */
  public String paintletTipText() {
    return "painlet for plotting the vs fit plot";
  }
}
